//////////////////////////////////////////////////
//TRISS - Triangular Robot Inspiring awesomeneSS//
//////////////////////////////////////////////////

#pragma config(Motor,  port6,           MOT1,          tmotorNormal, openLoop, reversed)
#pragma config(Motor,  port7,           MOT2,          tmotorNormal, openLoop, reversed)
#pragma config(Motor,  port8,           MOT3,          tmotorNormal, openLoop, reversed)
//*!!Code automatically generated by 'ROBOTC' configuration wizard               !!*//

//Use Rx2 port (comment out the #define statements to use Rx1)
#define Ch1 Ch1Xmtr2
#define Ch2 Ch2Xmtr2
#define Ch3 Ch3Xmtr2
#define Ch4 Ch4Xmtr2
#define Ch5 Ch5Xmtr2
#define Ch6 Ch6Xmtr2

task main(){
	bIfiAutonomousMode = false; //Activates Remote Control Mode
	bool dbflag = false;        //Deadband - Ignore Tx when it's absolute value is less than this
	int  db	= 5;    //value of the deadband, useless if deadband == false
	int  scl;       //Scale - Ratio for scaling motors when the input is too great
	int  max = 127; //Maximum acceptable value of motors - used in scl

	int m1; //Mixable motor input
	int m2; //Mixable motor input
	int m3; //Mixable motor input

	while(1){
		m1 = 0;
		m2 = 0;
		m3 = 0;

		if(!dbflag){ //Mix motors from Tx input. Ch1/2 controls linear movement, Ch3/4 controls rotation
			//Forward/Backward
			m1 += vexRT[Ch1];
			m2 -= vexRT[Ch1] * 3/10;
			m3 -= vexRT[Ch1] * 6/10;

			//Left/Right
			m2 += vexRT[Ch2];
			m1 -= vexRT[Ch2] * 6/10;
			m3 -= vexRT[Ch2] * 3/10;

			//Clockwise/CCW
			m1 += vexRT[Ch3] / 2;
			m2 += vexRT[Ch3] / 2;
			m3 += vexRT[Ch3] / 2;
			m1 -= vexRT[Ch4] / 2;
			m2 -= vexRT[Ch4] / 2;
			m3 -= vexRT[Ch4] / 2;
		}else{ //Mix motors from Tx input with respect to deadband. Ch1/2 controls linear movement, Ch3 controls rotation
			//Forward/Backward
			if(abs(vexRT[Ch1]) > db){
				m1 += vexRT[Ch1];
				m2 -= vexRT[Ch1] * 3/10;
				m3 -= vexRT[Ch1] * 6/10;
			}
			//Left/Right
			if(abs(vexRT[Ch2]) > db){
				m2 += vexRT[Ch2];
				m1 -= vexRT[Ch2] * 6/10;
				m3 -= vexRT[Ch2] * 3/10;
			}
			//Clockwise/CCW
			if(abs(vexRT[Ch3]) > db || abs(vexRT[Ch4]) > db){
				m1 += vexRT[Ch3] / 2;
				m2 += vexRT[Ch3] / 2;
				m3 += vexRT[Ch3] / 2;
				m1 -= vexRT[Ch4] / 2;
				m2 -= vexRT[Ch4] / 2;
				m3 -= vexRT[Ch4] / 2;
			}
		}

		//If any motor inputs are bigger than full power (127), scale them all down so only one motor is at full power
		if(abs(m1) > max || abs(m2) > max || abs(m3) > max){
			if(abs(m1) > abs(m2) && abs(m1) > abs(m3))  scl = abs(m1) / max; //m1 needs full power, scale others down
			else if(abs(m2) > abs(m3))                  scl = abs(m2) / max; //m2 needs full power, scale others down
			else                                        scl = abs(m3) / max; //m3 needs full power, scale others down
		}else scl = 1;
		m1 /= scl;
		m2 /= scl;
		m3 /= scl;

		//Set the motors to the scaled values
		motor[MOT1] = m1;
		motor[MOT2] = m2;
		motor[MOT3] = m3;
	}
}
